import { AngularFireAuth } from '@angular/fire/auth';
import { AngularFirestore } from '@angular/fire/firestore';
import { auth, User } from 'firebase/app';
import 'firebase/auth';
import { Observable } from 'rxjs';
import { Store } from '@datorama/akita';
import { FireAuthState } from './auth.model';
import { AtomicWrite } from '../utils/types';
export declare const fireAuthProviders: readonly ["github", "google", "microsoft", "facebook", "twitter", "email"];
declare type FireProvider = (typeof fireAuthProviders)[number];
export declare class FireAuthService<S extends FireAuthState> {
    protected store: Store<S>;
    private collection;
    protected collectionPath: string;
    protected fireAuth: AngularFireAuth;
    protected db: AngularFirestore;
    protected onCreate?(profile: S['profile'], write: AtomicWrite): any;
    protected onUpdate?(profile: S['profile'], write: AtomicWrite): any;
    protected onDelete?(write: AtomicWrite): any;
    constructor(store: Store<S>);
    /** Can be overrided */
    protected selectProfile(user: User): Observable<S['profile']>;
    /** Can be overrided */
    protected selectRoles(user: User): Promise<S['roles']> | Observable<S['roles']>;
    /** Should be override */
    protected createProfile(user: User): Promise<Partial<S['profile']>> | Partial<S['profile']>;
    /** The current sign-in user (or null) */
    readonly user: User;
    /** The path to the profile in firestore */
    readonly path: any;
    /** Start listening on User */
    sync(): Observable<any[]>;
    /**
     * @description Delete user from authentication service and database
     * WARNING This is security sensitive operation
     */
    delete(): Promise<void>;
    /** Update the current profile of the authenticated user */
    update(profile: Partial<S['profile']>): Promise<void>;
    /** Create a user based on email and password */
    signup(email: string, password: string): Promise<auth.UserCredential>;
    signin(email: string, password: string): Promise<auth.UserCredential>;
    signin(provider?: FireProvider): Promise<auth.UserCredential>;
    signin(token: string): Promise<auth.UserCredential>;
    /** Signs out the current user */
    signOut(): Promise<void>;
}
export {};
